@@ -1,5 +1,5 @@
 """
-Easy image file reading & writing. Supports PGM/PPM/PNM/PFM/PNG/BMP/JPG/TIFF/EXR/RAW.
+Easy image file reading & writing.
 
 Example:
   image, maxval = imgio.imread("foo.png")
@@ -8,7 +8,8 @@ Example:
 https://github.com/toaarnio/imgio
 """
 
+from .version import __version__
+
 from .imgio import *
 
-__version__ = "0.9.1"
-__all__ = ["imread", "imwrite", "selftest"]
+__all__ = ["__version__", "imread", "imread_f16", "imread_f32", "imread_f64", "imwrite", "selftest"]
