@@ -18,13 +18,17 @@ def read(filename, verbose=False):
     factor' attribute is also returned. Both 1-channel and 3-channel images
     are supported, as well as both byte orders.
     """
-    with open(filename, 'rb') as f:
-        if verbose:
-            print("Reading file %s "%(filename), end='')
+    with open(filename, "rb") as f:
         buf = f.read()
-        parsed = parse(buf, verbose)
+        parsed = parse(buf)
         if parsed is not None:
             pixels, scale = parsed
+            if verbose:
+                maxx = np.max(pixels)
+                h, w = pixels.shape[:2]
+                ch = pixels.shape[2] if pixels.ndim == 3 else 1
+                infostr = "(w=%d, h=%d, c=%d, scale=%.2f, max=%.2f)"%(w, h, ch, scale, maxx)
+                print("Reading file %s %s"%(filename, infostr))
             return pixels, scale
         raise RuntimeError("File %s is not a valid PFM file."%(filename))
 
@@ -35,13 +39,13 @@ def write(filename, pixels, scale=1.0, little_endian=True, verbose=False):
     supported. The shape of the given array must be (h, w) or (h, w, c),
     where c is either 1 or 3.
     """
-    with open(filename, 'wb') as f:
+    with open(filename, "wb") as f:
         if verbose:
-            print("Writing file %s "%(filename), end='')
+            print("Writing file %s "%(filename), end="")
         pfm_bytearray = generate(pixels, scale, little_endian, verbose)
         f.write(pfm_bytearray)
 
-def parse(pfm_bytearray, verbose=False):
+def parse(pfm_bytearray):
     """
     Converts the given byte array, representing the contents of a PFM file, into
     a 1-channel or 3-channel numpy ndarray with float32 elements. Returns a tuple
@@ -60,9 +64,6 @@ def parse(pfm_bytearray, verbose=False):
         f32 = np.frombuffer(pfm_bytearray, dtype=dtype, count=width * height * numchannels, offset=len(header))
         f32 = f32.reshape((height, width) if numchannels == 1 else (height, width, 3))
         f32 = f32.astype(np.float32)
-        if verbose:
-            maxx = np.max(f32)
-            print("(w=%d, h=%d, c=%d, scale=%.2f, max=%.2f, byteorder='%s')"%(width, height, numchannels, scale, maxx, dtype[0]))
         return f32, scale
     return None
 
@@ -91,6 +92,6 @@ def generate(pixels, scale=1.0, little_endian=True, verbose=False):
         f32bs = f32.byteswap()
     if verbose:
         print("(w=%d, h=%d, c=%d, scale=%.3f, byteorder='%s')"%(width, height, numchannels, abs(scale), byteorder))
-    pfm_bytearray = bytearray("%s %d %d %.3f\n"%(typestr, width, height, scale), 'utf-8')
+    pfm_bytearray = bytearray("%s %d %d %.3f\n"%(typestr, width, height, scale), "utf-8")
     pfm_bytearray.extend(f32bs.flatten())
     return bytes(pfm_bytearray)
